using System;
using System.Windows.Forms;
using UiPath.CodedWorkflows;
using UiPath.OpenAI.IntegrationService.Activities;


namespace First_Coded_Workflow
{
    public class WikipediaSearch : CodedWorkflow
    {
					
			// 1. Access your OpenAI. Replace with your API key as a string.
		private static readonly string OpenAiApiKey = Environment.GetEnvironmentVariable("OPEN_AI_API_KEY"); 
		
        [Workflow]
        public void Execute()
        {
            // To start using services, use IntelliSense (CTRL + Space) to discover the available services:
            // e.g. system.GetAsset(...)
			
			// 2. Open the main Wikipedia page
            var wikiScreen= uiAutomation.Open("WikiMainScreen");
			
			// 2. Search for "uipath"
			wikiScreen.TypeInto("SearchBar", "uipath");
			
			// 3. Click the search button to perform the search
			wikiScreen.Click("SearchButton");
			
			// 4. Retrieve the description about UiPath
			var uipathWikiPage = uiAutomation.Attach("UiPathWikiPage");
			var uipathWikiDescription = uipathWikiPage.GetText("UiPathDescription");
			Log("This is the UiPath's wikipedia description: " + uipathWikiDescription);
			
			// 5. Give it to ChatGPT and ask it to rewrite it
			var api = new OpenAiApiKey(OpenAiApiKey);
			var chatResult = api.Chat.GenerateChatCompletionAsync(
				"Please rewrite the following description about UiPath: '" + uipathWikiDescription + "', as if humanity and society exist naturally on Saturn.").Result;
			
			// 6. Display the result inside a message box
			Message.Show(chatResult.Choices[0].Message.Content);
			
        }
    }

    internal class OpenAiApiKey
    {
        public OpenAiApiKey(string openAiApiKey)
        {
            OpenAiApiKey = Environment.GetEnvironmentVariable("OPEN_AI_API_KEY");
        }
    }
}